==> zio-aws-cloudfront_2.13-5.17.157.2-sources.jar: zio/aws/cloudfront/model/GetPublicKeyResponse.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetPublicKeyResponse(
    publicKey: Option[zio.aws.cloudfront.model.PublicKey] = None,
    eTag: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.GetPublicKeyResponse = {
    import GetPublicKeyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.GetPublicKeyResponse
      .builder()
      .optionallyWith(publicKey.map(value => value.buildAwsValue()))(
        _.publicKey
      )
      .optionallyWith(eTag.map(value => value: java.lang.String))(_.eTag)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.GetPublicKeyResponse.ReadOnly =
    zio.aws.cloudfront.model.GetPublicKeyResponse.wrap(buildAwsValue())
}
object GetPublicKeyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.GetPublicKeyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.GetPublicKeyResponse =
      zio.aws.cloudfront.model.GetPublicKeyResponse(
        publicKey.map(value => value.asEditable),
        eTag.map(value => value)
      )
    def publicKey: Option[zio.aws.cloudfront.model.PublicKey.ReadOnly]
    def eTag: Option[String]
    def getPublicKey
        : ZIO[Any, AwsError, zio.aws.cloudfront.model.PublicKey.ReadOnly] =
      AwsError.unwrapOptionField("publicKey", publicKey)
    def getETag: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("eTag", eTag)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.GetPublicKeyResponse
  ) extends zio.aws.cloudfront.model.GetPublicKeyResponse.ReadOnly {
    override val publicKey
        : Option[zio.aws.cloudfront.model.PublicKey.ReadOnly] = scala
      .Option(impl.publicKey())
      .map(value => zio.aws.cloudfront.model.PublicKey.wrap(value))
    override val eTag: Option[String] =
      scala.Option(impl.eTag()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.GetPublicKeyResponse
  ): zio.aws.cloudfront.model.GetPublicKeyResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-cloudfront_2.13-5.19.17.1-sources.jar: zio/aws/cloudfront/model/GetPublicKeyResponse.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetPublicKeyResponse(
    publicKey: Optional[zio.aws.cloudfront.model.PublicKey] = Optional.Absent,
    eTag: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.GetPublicKeyResponse = {
    import GetPublicKeyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.GetPublicKeyResponse
      .builder()
      .optionallyWith(publicKey.map(value => value.buildAwsValue()))(
        _.publicKey
      )
      .optionallyWith(eTag.map(value => value: java.lang.String))(_.eTag)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.GetPublicKeyResponse.ReadOnly =
    zio.aws.cloudfront.model.GetPublicKeyResponse.wrap(buildAwsValue())
}
object GetPublicKeyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.GetPublicKeyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.GetPublicKeyResponse =
      zio.aws.cloudfront.model.GetPublicKeyResponse(
        publicKey.map(value => value.asEditable),
        eTag.map(value => value)
      )
    def publicKey: Optional[zio.aws.cloudfront.model.PublicKey.ReadOnly]
    def eTag: Optional[String]
    def getPublicKey
        : ZIO[Any, AwsError, zio.aws.cloudfront.model.PublicKey.ReadOnly] =
      AwsError.unwrapOptionField("publicKey", publicKey)
    def getETag: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("eTag", eTag)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.GetPublicKeyResponse
  ) extends zio.aws.cloudfront.model.GetPublicKeyResponse.ReadOnly {
    override val publicKey
        : Optional[zio.aws.cloudfront.model.PublicKey.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.publicKey())
        .map(value => zio.aws.cloudfront.model.PublicKey.wrap(value))
    override val eTag: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.eTag())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.GetPublicKeyResponse
  ): zio.aws.cloudfront.model.GetPublicKeyResponse.ReadOnly = new Wrapper(impl)
}
